==> TOBY-L201-02S-03_FW20.06_A01.01_IP_UFWINSTALL.zip: system/marvell/tel/run_nw_conf.sh <==
#!/bin/sh

CmdLine="/NVM/cmdline"

IP_TERMINATION_AUX=`grep "IPTM=5" $CmdLine|wc -l`
SYSTEM_CONFIG_HOST=`grep "SYCG=3" $CmdLine|wc -l`
MIFI_ENABLE=`grep "MIFI=1" $CmdLine|wc -l`

##### u-blox modifications #####
RNDIS0_IPADDR=`getprop persist.sys.ublx_rndis0_ipaddr`
RNDIS0_IPMASK=`getprop persist.sys.ublx_rndis0_ipmask`
if [ -z "$RNDIS0_IPADDR" ] || [ -z "$RNDIS0_IPMASK" ]; then
setprop persist.sys.ublx_rndis0_ipaddr 192.168.1.1
setprop persist.sys.ublx_rndis0_ipmask 255.255.255.0
RNDIS0_IPADDR=`getprop persist.sys.ublx_rndis0_ipaddr`
RNDIS0_IPMASK=`getprop persist.sys.ublx_rndis0_ipmask`
fi
##### u-blox modifications #####


if [ $IP_TERMINATION_AUX = '0' ]; then
    echo "Running HOST mode..." >> /dev/kmsg
    UserTest=`grep "BOAR=c4" $CmdLine|wc -l`
    if [ "$UserTest" = '1' ]; then
##### u-blox modifications #####
#        set_usb_ip="usb0 192.168.42.129 netmask 255.255.255.0"
        set_usb_ip="usb0 $RNDIS0_IPADDR netmask $RNDIS0_IPMASK"
##### u-blox modifications #####
    else
##### u-blox modifications #####
#        set_usb_ip="usb0 192.168.1.1 netmask 255.255.255.0"
        set_usb_ip="usb0 $RNDIS0_IPADDR netmask $RNDIS0_IPMASK"
 
##### u-blox modifications #####
    fi
    busybox ifconfig $set_usb_ip up
    echo "Running HOST mode... UserTest $UserTest - $set_usb_ip" >> /dev/kmsg
fi

if [ $IP_TERMINATION_AUX = '1' ]; then
    echo "Running HOSTLESS mode..." >> /dev/kmsg
	if [ $MIFI_ENABLE = '0' -a $SYSTEM_CONFIG_HOST = '0' ]; then
##### u-blox modifications #####
#               busybox ifconfig usb0 192.168.1.1 netmask 255.255.255.0 up
                busybox ifconfig usb0 $RNDIS0_IPADDR netmask $RNDIS0_IPMASK up
##### u-blox modifications #####
	fi

    #U_M39G_MV-1114
    UBLOX_FPATH_ENABLE=`getprop persist.sys.ublx_udconf_67`

    #if we have any issue with the property get then we load the fastpath anyway
    if [ "$UBLOX_FPATH_ENABLE" == "0" ]; then
      echo "fastpath load disabled by UDCONF=67" > /dev/kmsg
    else
      insmod fastpath.ko
      echo "fastpath load enabled by UDCONF=67" > /dev/kmsg
    fi
    #U_M39G_MV-1114

    echo 1 > /proc/sys/net/ipv4/ip_forward

    # NAT rules:
    #./iptables -t nat -A POSTROUTING -o ccinet0 -j MASQUERADE
    #./iptables -A FORWARD -i ccinet0 -o usb0 -m state --state RELATED,ESTABLISHED -j ACCEPT
    #./iptables -A FORWARD -i usb0 -o ccinet0 -j ACCEPT
    #./iptables -t nat -A POSTROUTING -o ccinet3 -j MASQUERADE
    #./iptables -A FORWARD -i ccinet3 -o usb0 -m state --state RELATED,ESTABLISHED -j ACCEPT
    #./iptables -A FORWARD -i usb0 -o ccinet3 -j ACCEPT

    # Special rules for a new session starts from NW to PC
    #
    # Note:
    # 1. It relays on DHCP address allocation (currently hard coded)
    # 2. This rules are for development only and should be removed in a product!
    #./iptables -A PREROUTING -t nat -i ccinet0 -j DNAT --to-destination 192.168.42.149
    #./iptables -A PREROUTING -t nat -i ccinet3 -j DNAT --to-destination 192.168.42.149

    mkdir -p /data/misc/dhcp
    mkdir -p /var/run
    #rm /marvell/tel/dnsmasq.leases
    #./dnsmasq -K -C ./dnsmasq.conf < /dev/tty0

    # Setting DNS server.
    # NOTE: This line should be removed when connectivity manager will be ready.
    setprop net.dns1 8.8.8.8
fi

==> TOBY-L210-03S-03_FW17.00_A01.01_IP_UFWINSTALL.zip: system/marvell/tel/run_nw_conf.sh <==
#!/bin/sh

IP_TERMINATION_AUX=0
if [ `getprop persist.sys.ublx_cmdline.IPTM` = 5 ]; then
	IP_TERMINATION_AUX=1
fi

SYSTEM_CONFIG_HOST=0
if [ `getprop persist.sys.ublx_cmdline.SYCG` = 3 ]; then
	SYSTEM_CONFIG_HOST=1
fi

MIFI_ENABLE=`getprop persist.sys.ublx_cmdline.MORO`
#IP_ADDRESS=`getprop persist.mrvl.net.static_ip`
##### u-blox modifications #####
RNDIS0_IPADDR=`getprop persist.sys.ublx_rndis0_ipaddr`
RNDIS0_IPMASK=`getprop persist.sys.ublx_rndis0_ipmask`
if [ -z "$RNDIS0_IPADDR" ] || [ -z "$RNDIS0_IPMASK" ]; then
setprop persist.sys.ublx_rndis0_ipaddr 192.168.1.1
setprop persist.sys.ublx_rndis0_ipmask 255.255.255.0
RNDIS0_IPADDR=`getprop persist.sys.ublx_rndis0_ipaddr`
RNDIS0_IPMASK=`getprop persist.sys.ublx_rndis0_ipmask`
fi
##### u-blox modifications #####

if [ $IP_TERMINATION_AUX = '0' ]; then
    echo "Running HOST mode..." >> /dev/kmsg
    UserTest=`getprop ro.cmdline.BOAR`

    if [ "$UserTest" = 'c4' ]; then
##### u-blox modifications #####
#        set_usb_ip="usb0 192.168.42.129 netmask 255.255.255.0"
        set_usb_ip="usb0 $RNDIS0_IPADDR netmask $RNDIS0_IPMASK"
##### u-blox modifications #####
    else
##### u-blox modifications #####
#        set_usb_ip="usb0 $IP_ADDRESS netmask 255.255.255.0"
        set_usb_ip="usb0 $RNDIS0_IPADDR netmask $RNDIS0_IPMASK"
 
##### u-blox modifications #####
    fi
    echo 1 > /proc/sys/net/ipv6/conf/all/forwarding
    busybox ifconfig $set_usb_ip up
    echo "Running HOST mode... UserTest $UserTest - $set_usb_ip" >> /dev/kmsg
fi

if [ $IP_TERMINATION_AUX = '1' ]; then
    echo "Running HOSTLESS mode..." >> /dev/kmsg
# M39G_MV_2-364
#   if [ $MIFI_ENABLE = '0' -a $SYSTEM_CONFIG_HOST = '0' ]; then
	if [ $SYSTEM_CONFIG_HOST = '0' ]; then
##### u-blox modifications #####
#		busybox ifconfig usb0 $IP_ADDRESS netmask 255.255.255.0 up
                busybox ifconfig usb0 $RNDIS0_IPADDR netmask $RNDIS0_IPMASK up
##### u-blox modifications #####
	fi

    #U_M39G_MV-1114
    UBLOX_FPATH_ENABLE=`getprop persist.sys.ublx_udconf_67`

    #if we have any issue with the property get then we load the fastpath anyway
    if [ "$UBLOX_FPATH_ENABLE" == "0" ]; then
      echo "fastpath load disabled by UDCONF=67" > /dev/kmsg
    else
      insmod fastpath.ko
      echo "fastpath load enabled by UDCONF=67" > /dev/kmsg
    fi
    #U_M39G_MV-1114

    echo 1 > /proc/sys/net/ipv4/ip_forward

    # NAT rules:
    #./iptables -t nat -A POSTROUTING -o ccinet0 -j MASQUERADE
    #./iptables -A FORWARD -i ccinet0 -o usb0 -m state --state RELATED,ESTABLISHED -j ACCEPT
    #./iptables -A FORWARD -i usb0 -o ccinet0 -j ACCEPT
    #./iptables -t nat -A POSTROUTING -o ccinet3 -j MASQUERADE
    #./iptables -A FORWARD -i ccinet3 -o usb0 -m state --state RELATED,ESTABLISHED -j ACCEPT
    #./iptables -A FORWARD -i usb0 -o ccinet3 -j ACCEPT

    # Special rules for a new session starts from NW to PC
    #
    # Note:
    # 1. It relays on DHCP address allocation (currently hard coded)
    # 2. This rules are for development only and should be removed in a product!
    #./iptables -A PREROUTING -t nat -i ccinet0 -j DNAT --to-destination 192.168.42.149
    #./iptables -A PREROUTING -t nat -i ccinet3 -j DNAT --to-destination 192.168.42.149

    mkdir -p /data/misc/dhcp
    mkdir -p /var/run
    #rm /marvell/tel/dnsmasq.leases
    #dnsmasq -K -C ./dnsmasq.conf < /dev/tty0

# M39G_MV_2-3313
#    # Setting DNS server.
#    # NOTE: This line should be removed when connectivity manager will be ready.
#    setprop net.dns1 8.8.8.8
fi

# M39G_MV_2-3313
setprop net.dns1 127.0.0.1
